Index: chrome/common/chrome_switches.cc |
diff --git a/chrome/common/chrome_switches.cc b/chrome/common/chrome_switches.cc |
index b8b5964a81bc7b18e5033575ff8bfc86ac9e7571..f5117cc61fab42820ee6f3411cf028001a40b5ed 100644 |
--- a/chrome/common/chrome_switches.cc |
+++ b/chrome/common/chrome_switches.cc |
@@ -422,8 +422,8 @@ const char kDisableSyncTypedUrls[] = "disable-sync-typed-urls"; |
// disable translate with the preference. |
const char kDisableTranslate[] = "disable-translate"; |
-// Disables TLS Channel ID extension. |
-const char kDisableTLSChannelID[] = "disable-tls-channel-id"; |
+// Enable TLS Channel ID extension. |
+const char kEnableTLSChannelID[] = "enable-tls-channel-id"; |
// Disables the backend service for web resources. |
const char kDisableWebResources[] = "disable-web-resources"; |